@@ -22,7 +22,7 @@ import GameCheck
 import GUICommon
 import Portrait
 from GUIDefines import *
-from ie_stats import IE_SEX, IE_CLASS, IE_RACE, IE_MC_FLAGS, MC_EXPORTABLE
+from ie_stats import IE_SEX, IE_RACE, IE_MC_FLAGS, MC_EXPORTABLE
 from ie_restype import RES_WAV
 
 BiographyWindow = None
@@ -235,14 +235,14 @@ def OpenCustomPortraitWindow ():
 	# Portrait List Large
 	PortraitList1 = SubSubCustomizeWindow.GetControl (2)
 	RowCount1 = PortraitList1.ListResources (CHR_PORTRAITS, 0)
-	PortraitList1.SetEvent (IE_GUI_TEXTAREA_ON_CHANGE, LargeCustomPortrait)
+	PortraitList1.SetEvent (IE_GUI_TEXTAREA_ON_SELECT, LargeCustomPortrait)
 	GemRB.SetVar ("Row1", RowCount1)
 	PortraitList1.SetVarAssoc ("Row1",RowCount1)
 
 	# Portrait List Small
 	PortraitList2 = SubSubCustomizeWindow.GetControl (3)
 	RowCount2 = PortraitList2.ListResources (CHR_PORTRAITS, 1)
-	PortraitList2.SetEvent (IE_GUI_TEXTAREA_ON_CHANGE, SmallCustomPortrait)
+	PortraitList2.SetEvent (IE_GUI_TEXTAREA_ON_SELECT, SmallCustomPortrait)
 	GemRB.SetVar ("Row2", RowCount2)
 	PortraitList2.SetVarAssoc ("Row2",RowCount2)
 
@@ -384,29 +384,36 @@ def OpenScriptWindow ():
 	SubCustomizeWindow = GemRB.LoadWindow (11)
 
 	ScriptTextArea = SubCustomizeWindow.GetControl (2)
-	row = ScriptsTable.GetRowCount ()
-	
+	scriptCount = ScriptTextArea.ListResources (CHR_SCRIPTS)
+	defaultCount = ScriptsTable.GetRowCount ()
+
 	options = []
-	for i in range (row):
-		GemRB.SetToken ("script", ScriptsTable.GetRowName (i) )
-		title = ScriptsTable.GetValue (i,0)
-		if title!=-1:
-			desc = ScriptsTable.GetValue (i,1)
-			txt = GemRB.GetString (title)
-			if (desc!=-1):
-				txt += GemRB.GetString (desc) + "\n"
-			options.append(txt) 
+	tat = ScriptTextArea.QueryText ().split("\n")
+	tat.pop() # last item is empty
+	for i in range (scriptCount):
+		script = tat[i]
+		if i < defaultCount:
+			GemRB.SetToken ("script", ScriptsTable.GetRowName (i))
+			title = ScriptsTable.GetValue (i,0)
+			if title!=-1:
+				  desc = ScriptsTable.GetValue (i,1)
+				  txt = GemRB.GetString (title)
+				  if (desc!=-1):
+					  txt += GemRB.GetString (desc) + "\n"
+				  options.append(txt)
+			else:
+				  options.append (ScriptsTable.GetRowName (i) + "\n")
 		else:
-			options.append (ScriptsTable.GetRowName (i) + "\n")
-	ScriptTextArea.SetOptions (options)
-	
+			GemRB.SetToken ("script", script)
+			options.append (17167)
+
 	pc = GemRB.GameGetSelectedPCSingle ()
 	script = GemRB.GetPlayerScript (pc)
 	if script == None:
 		script = "None"
 	scriptindex = ScriptsTable.GetRowIndex (script)
 	GemRB.SetVar ("Selected", scriptindex)
-	ScriptTextArea.SetVarAssoc ("Selected", scriptindex)
+	ScriptTextArea.SetOptions (options, "Selected", scriptindex)
 
 	SelectedTextArea = SubCustomizeWindow.GetControl (4)
 	UpdateScriptSelection ()
