@@ -31,6 +31,8 @@
 #include "Plugin.h"
 #include "System/DataStream.h"
 
+namespace GemRB {
+
 /**
  * @class DataFileMgr
  * Abstract loader for .INI files
@@ -40,7 +42,7 @@ class GEM_EXPORT DataFileMgr : public Plugin {
 public:
 	DataFileMgr(void);
 	virtual ~DataFileMgr(void);
-	virtual bool Open(DataStream* stream, bool autoFree = false) = 0;
+	virtual bool Open(DataStream* stream) = 0;
 	virtual int GetTagsCount() const = 0;
 	virtual const char* GetTagNameByIndex(int index) const = 0;
 	virtual int GetKeysCount(const char* Tag) const = 0;
@@ -55,4 +57,6 @@ public:
 		const bool Default) const = 0;
 };
 
+}
+
 #endif
