@@ -24,10 +24,12 @@
 #include "System/FileStream.h"
 #include "System/VFS.h"
 
+namespace GemRB {
+
 DataStream* CacheCompressedStream(DataStream *stream, const char* filename, int length, bool overwrite)
 {
 	if (!core->IsAvailable(PLUGIN_COMPRESSION_ZLIB)) {
-		print( "No Compression Manager Available.\nCannot Load Compressed File.\n" );
+		Log(ERROR, "FileCache", "No Compression Manager Available. Cannot Load Compressed File.");
 		return NULL;
 	}
 
@@ -39,7 +41,7 @@ DataStream* CacheCompressedStream(DataStream *stream, const char* filename, int
 	if (overwrite || !file_exists(path)) {
 		FileStream out;
 		if (!out.Create(path)) {
-			printMessage("FileCache", "Cannot write %s.\n", RED, path);
+			Log(ERROR, "FileCache", "Cannot write %s.", path);
 			return NULL;
 		}
 
@@ -52,35 +54,4 @@ DataStream* CacheCompressedStream(DataStream *stream, const char* filename, int
 	return FileStream::OpenFile(path);
 }
 
-DataStream* CacheStream(DataStream* src)
-{
-	src->Seek(0, GEM_STREAM_START);
-	if (!core->SlowBIFs)
-		return src;
-
-	char cachedfile[_MAX_PATH];
-	PathJoin(cachedfile, core->CachePath, src->filename, NULL);
-
-	if (!file_exists(cachedfile)) {    // File was not found in cache
-		FileStream dest;
-		if (!dest.Create(cachedfile)) {
-			error("Cache", "CachedFile failed to write to cached file '%s' (from '%s')\n", cachedfile, src->originalfile);
-		}
-
-		size_t blockSize = 1024 * 1000;
-		char buff[1024 * 1000];
-		do {
-			if (blockSize > src->Remains())
-				blockSize = src->Remains();
-			size_t len = src->Read(buff, blockSize);
-			size_t c = dest.Write(buff, len);
-			if (c != len) {
-				error("Cache", "CacheFile failed to write to cached file '%s' (from '%s')\n", cachedfile, src->originalfile);
-			}
-		} while (src->Remains());
-	}
-
-	delete src;
-
-	return FileStream::OpenFile(cachedfile);
 }
