@@ -174,11 +174,6 @@ void Button::DrawInternal(Region& rgn)
 		Sprite2D* Image = NULL;
 
 		switch (State) {
-			case IE_GUI_BUTTON_UNPRESSED:
-			case IE_GUI_BUTTON_LOCKED:
-			case IE_GUI_BUTTON_LOCKED_PRESSED:
-				Image = buttonImages[BUTTON_IMAGE_UNPRESSED];
-				break;
 			case IE_GUI_BUTTON_FAKEPRESSED:
 			case IE_GUI_BUTTON_PRESSED:
 				Image = buttonImages[BUTTON_IMAGE_PRESSED];
@@ -190,9 +185,9 @@ void Button::DrawInternal(Region& rgn)
 			case IE_GUI_BUTTON_FAKEDISABLED:
 				Image = buttonImages[BUTTON_IMAGE_DISABLED];
 				break;
-		}
-		if (!Image) {
-			Image = buttonImages[BUTTON_IMAGE_UNPRESSED];
+			default:
+				Image = buttonImages[BUTTON_IMAGE_UNPRESSED];
+				break;
 		}
 		if (Image) {
 			// FIXME: maybe it's useless...
@@ -209,19 +204,6 @@ void Button::DrawInternal(Region& rgn)
 		rgn.y += PushOffset.y;
 	}
 
-	// Button picture
-	if (AnimPicture) {
-		int xOffs = ( Width / 2 ) - ( AnimPicture->Width / 2 );
-		int yOffs = ( Height / 2 ) - ( AnimPicture->Height / 2 );
-		Region r( rgn.x + xOffs, rgn.y + yOffs, (int)(AnimPicture->Width * Clipping), AnimPicture->Height );
-
-		if (Flags & IE_GUI_BUTTON_CENTER_PICTURES) {
-			video->BlitSprite( AnimPicture, rgn.x + xOffs + AnimPicture->XPos, rgn.y + yOffs + AnimPicture->YPos, true, &r );
-		} else {
-			video->BlitSprite( AnimPicture, rgn.x + xOffs, rgn.y + yOffs, true, &r );
-		}
-	}
-
 	// Button picture
 	int picXPos = 0, picYPos = 0;
 	if (Picture && (Flags & IE_GUI_BUTTON_PICTURE) ) {
@@ -259,6 +241,19 @@ void Button::DrawInternal(Region& rgn)
 		}
 	}
 
+	// Button animation
+	if (AnimPicture) {
+		int xOffs = ( Width / 2 ) - ( AnimPicture->Width / 2 );
+		int yOffs = ( Height / 2 ) - ( AnimPicture->Height / 2 );
+		Region r( rgn.x + xOffs, rgn.y + yOffs, (int)(AnimPicture->Width * Clipping), AnimPicture->Height );
+
+		if (Flags & IE_GUI_BUTTON_CENTER_PICTURES) {
+			video->BlitSprite( AnimPicture, rgn.x + xOffs + AnimPicture->XPos, rgn.y + yOffs + AnimPicture->YPos, true, &r );
+		} else {
+			video->BlitSprite( AnimPicture, rgn.x + xOffs, rgn.y + yOffs, true, &r );
+		}
+	}
+
 	// Composite pictures (paperdolls/description icons)
 	if (!PictureList.empty() && (Flags & IE_GUI_BUTTON_PICTURE) ) {
 		std::list<Sprite2D*>::iterator iter = PictureList.begin();
@@ -676,11 +671,8 @@ bool Button::SetEvent(int eventType, ControlEventHandler handler)
 }
 
 /** Refresh a button from a given radio button group */
-void Button::UpdateState(const char* VariableName, unsigned int Sum)
+void Button::UpdateState(unsigned int Sum)
 {
-	if (strnicmp( VarName, VariableName, MAX_VARIABLE_LENGTH )) {
-		return;
-	}
 	if (State == IE_GUI_BUTTON_DISABLED) {
 		return;
 	}
