@@ -228,8 +228,7 @@ void GameControl::CreateMovement(Actor *actor, const Point &p)
 	static bool CanRun = true;
 
 	//try running (in PST) only if not encumbered
-	ieDword speed = actor->CalculateSpeed(true);
-	if ( (speed==actor->GetStat(IE_MOVEMENTRATE)) && CanRun && (DoubleClick || AlwaysRun)) {
+	if (CanRun && ShouldRun(actor)) {
 		sprintf( Tmp, "RunToPoint([%d.%d])", p.x, p.y );
 		action = GenerateAction( Tmp );
 		//if it didn't work don't insist
@@ -244,6 +243,17 @@ void GameControl::CreateMovement(Actor *actor, const Point &p)
 	actor->CommandActor(action);
 }
 
+// were we instructed to run and can handle it (no movement impairments)?
+bool GameControl::ShouldRun(Actor *actor) const
+{
+	if (!actor) return false;
+	ieDword speed = actor->CalculateSpeed(true);
+	if (speed != actor->GetStat(IE_MOVEMENTRATE)) {
+		return false;
+	}
+	return (DoubleClick || AlwaysRun);
+}
+
 GameControl::~GameControl(void)
 {
 	//releasing the viewport of GameControl
@@ -1538,6 +1548,7 @@ void GameControl::SetScrolling(bool scroll) {
 //generate action code for source actor to try to attack a target
 void GameControl::TryToAttack(Actor *source, Actor *tgt)
 {
+	if (source->GetStat(IE_SEX) == SEX_ILLUSION) return;
 	source->CommandActor(GenerateActionDirect( "NIDSpecial3()", tgt));
 }
 
@@ -1625,6 +1636,9 @@ void GameControl::TryToCast(Actor *source, const Point &tgt)
 		action->int0Parameter = spellSlot;
 		action->int1Parameter = spellIndex;
 		action->int2Parameter = UI_SILENT;
+                //for multi-shot items like BG wand of lightning
+                if (spellCount)
+                    action->int2Parameter |= UI_NOAURA|UI_NOCHARGE;
 	}
 	source->AddAction( action );
 	if (!spellCount) {
@@ -1645,7 +1659,7 @@ void GameControl::TryToCast(Actor *source, Actor *tgt)
 
 	// cannot target spells on invisible or sanctuaried creatures
 	// invisible actors are invisible, so this is usually impossible by itself, but improved invisibility changes that
-	if (source != tgt && tgt->Untargetable() ) {
+	if (source != tgt && tgt->Untargetable(spellName)) {
 		displaymsg->DisplayConstantStringName(STR_NOSEE_NOCAST, DMC_RED, source);
 		ResetTargetMode();
 		return;
@@ -1681,6 +1695,9 @@ void GameControl::TryToCast(Actor *source, Actor *tgt)
 		action->int0Parameter = spellSlot;
 		action->int1Parameter = spellIndex;
 		action->int2Parameter = UI_SILENT;
+                //for multi-shot items like BG wand of lightning
+                if (spellCount)
+                    action->int2Parameter |= UI_NOAURA|UI_NOCHARGE;
 	}
 	source->AddAction( action );
 	if (!spellCount) {
@@ -1691,18 +1708,20 @@ void GameControl::TryToCast(Actor *source, Actor *tgt)
 //generate action code for source actor to use talk to target actor
 void GameControl::TryToTalk(Actor *source, Actor *tgt)
 {
+	if (source->GetStat(IE_SEX) == SEX_ILLUSION) return;
 	//Nidspecial1 is just an unused action existing in all games
 	//(non interactive demo)
 	//i found no fitting action which would emulate this kind of
 	//dialog initation
 	source->SetModal(MS_NONE);
-	dialoghandler->targetID = tgt->GetGlobalID(); //this is a hack, but not so deadly
+	dialoghandler->SetTarget(tgt); //this is a hack, but not so deadly
 	source->CommandActor(GenerateActionDirect( "NIDSpecial1()", tgt));
 }
 
 //generate action code for actor appropriate for the target mode when the target is a container
 void GameControl::HandleContainer(Container *container, Actor *actor)
 {
+	if (actor->GetStat(IE_SEX) == SEX_ILLUSION) return;
 	//container is disabled, it should not react
 	if (container->Flags & CONT_DISABLED) {
 		return;
@@ -1737,6 +1756,7 @@ void GameControl::HandleContainer(Container *container, Actor *actor)
 //generate action code for actor appropriate for the target mode when the target is a door
 void GameControl::HandleDoor(Door *door, Actor *actor)
 {
+	if (actor->GetStat(IE_SEX) == SEX_ILLUSION) return;
 	if ((target_mode == TARGET_MODE_CAST) && spellCount) {
 		//we'll get the door back from the coordinates
 		Point *p = door->toOpen;
@@ -1771,6 +1791,7 @@ void GameControl::HandleDoor(Door *door, Actor *actor)
 //generate action code for actor appropriate for the target mode when the target is an active region (infopoint, trap or travel)
 bool GameControl::HandleActiveRegion(InfoPoint *trap, Actor * actor, Point &p)
 {
+	if (actor->GetStat(IE_SEX) == SEX_ILLUSION) return false;
 	if ((target_mode == TARGET_MODE_CAST) && spellCount) {
 		//we'll get the active region from the coordinates (if needed)
 		TryToCast(actor, p);
@@ -1790,6 +1811,12 @@ bool GameControl::HandleActiveRegion(InfoPoint *trap, Actor * actor, Point &p)
 			trap->GetCurrentArea()->LastGoCloser = 0;
 			return false;
 		case ST_TRIGGER:
+			// pst, eg. ar1500
+			if (trap->GetDialog()[0]) {
+				trap->AddAction(GenerateAction("Dialogue([PC])"));
+				return true;
+			}
+
 			// always display overhead text; totsc's ar0511 library relies on it
 			if (!trap->GetOverheadText().empty()) {
 				if (!trap->OverheadTextIsDisplaying()) {
@@ -1945,10 +1972,18 @@ void GameControl::OnMouseUp(unsigned short x, unsigned short y, unsigned short B
 					}
 					if (overInfoPoint) {
 						if (overInfoPoint->Type==ST_TRAVEL) {
-							int i = game->selected.size();
 							ieDword exitID = overInfoPoint->GetGlobalID();
-							while(i--) {
-								game->selected[i]->UseExit(exitID);
+							if (core->HasFeature(GF_TEAM_MOVEMENT)) {
+								// pst forces everyone to travel (eg. ar0201 outside_portal)
+								int i = game->GetPartySize(false);
+								while(i--) {
+									game->GetPC(i, false)->UseExit(exitID);
+								}
+							} else {
+								int i = game->selected.size();
+								while(i--) {
+									game->selected[i]->UseExit(exitID);
+								}
 							}
 						}
 						if (HandleActiveRegion(overInfoPoint, pc, p)) {
@@ -2475,26 +2510,14 @@ void GameControl::ChangeMap(Actor *pc, bool forced)
 	}
 }
 
-void GameControl::SetScreenFlags(int value, int mode)
+void GameControl::SetScreenFlags(unsigned int value, int mode)
 {
-	switch(mode) {
-		case BM_OR: ScreenFlags|=value; break;
-		case BM_NAND: ScreenFlags&=~value; break;
-		case BM_SET: ScreenFlags=value; break;
-		case BM_AND: ScreenFlags&=value; break;
-		case BM_XOR: ScreenFlags^=value; break;
-	}
+	core->SetBits(ScreenFlags, value, mode);
 }
 
-void GameControl::SetDialogueFlags(int value, int mode)
+void GameControl::SetDialogueFlags(unsigned int value, int mode)
 {
-	switch(mode) {
-		case BM_OR: DialogueFlags|=value; break;
-		case BM_NAND: DialogueFlags&=~value; break;
-		case BM_SET: DialogueFlags=value; break;
-		case BM_AND: DialogueFlags&=value; break;
-		case BM_XOR: DialogueFlags^=value; break;
-	}
+	core->SetBits(DialogueFlags, value, mode);
 }
 
 //copies a screenshot into a sprite
