@@ -170,11 +170,8 @@ void MapControl::Realize()
 	if (YCenter < 0) YCenter = 0;
 }
 
-void MapControl::UpdateState(const char *VariableName, unsigned int Sum)
+void MapControl::UpdateState(unsigned int Sum)
 {
-	if (strnicmp( VarName, VariableName, MAX_VARIABLE_LENGTH )) {
-		return;
-	}
 	Value = Sum;
 	MarkDirty();
 }
