@@ -336,7 +336,7 @@ bool TextArea::OnKeyPress(unsigned char Key, unsigned short /*Mod*/)
 
 	unsigned int lookupIdx = Key - '1';
 	if (lookupIdx < OptSpans.size()) {
-		UpdateState(VarName, lookupIdx);
+		UpdateState(lookupIdx);
 	}
 	return true;
 }
@@ -531,7 +531,7 @@ void TextArea::OnMouseUp(unsigned short /*x*/, unsigned short /*y*/,
 			}
 			optIdx++;
 		}
-		UpdateState(VarName, optIdx);
+		UpdateState(optIdx);
 	}
 }
 
@@ -540,9 +540,9 @@ void TextArea::OnMouseLeave(unsigned short /*x*/, unsigned short /*y*/)
 	ClearHover();
 }
 
-void TextArea::UpdateState(const char* VariableName, unsigned int optIdx)
+void TextArea::UpdateState(unsigned int optIdx)
 {
-	if (!VariableName[0] || optIdx >= OptSpans.size()) {
+	if (!VarName[0] || optIdx >= OptSpans.size()) {
 		return;
 	}
 	if (!selectOptions) {
@@ -574,6 +574,13 @@ String TextArea::QueryText() const
 {
 	if (selectedSpan) {
 		return selectedSpan->Text();
+	} else if (OptSpans.size()) {
+		String options;
+		for (size_t i = 0; i < OptSpans.size(); i++) {
+			options.append(OptSpans[i].second->Text());
+			options.append(L"\n");
+		}
+		return options;
 	}
 	return textContainer->Text();
 }
