@@ -24,6 +24,7 @@
 #include "strrefs.h"
 #include "defsounds.h"
 #include "ie_feats.h"
+#include "voodooconst.h"
 
 #include "AmbientMgr.h"
 #include "Audio.h"
@@ -118,6 +119,11 @@ void InitScriptTables()
 			rmodchr[charisma] = strtol(rmc->QueryField(0, charisma), NULL, 0);
 		}
 	}
+
+	// see note in voodooconst.h
+	if (core->HasFeature(GF_AREA_OVERRIDE)) {
+		MAX_OPERATING_DISTANCE = 40*3;
+	}
 }
 
 int GetReaction(Actor *target, Scriptable *Sender)
@@ -128,8 +134,7 @@ int GetReaction(Actor *target, Scriptable *Sender)
 	if (target->GetStat(IE_EA) == EA_PC) {
 		rep = core->GetGame()->Reputation/10-1;
 	} else {
-		//FIXME: shouldn't this be divided by 10?
-		rep = target->GetStat(IE_REPUTATION)-1;
+		rep = target->GetStat(IE_REPUTATION)/10-1;
 	}
 	if (rep<0) rep = 0;
 	else if (rep>=MAX_REP_COLUMN) rep=MAX_REP_COLUMN-1;
@@ -156,7 +161,7 @@ int GetHappiness(Scriptable* Sender, int reputation)
 	if (reputation > 200) {
 		reputation = 200;
 	}
-	return happiness[alignment][reputation/10-1];
+	return happiness[alignment-1][reputation/10-1];
 }
 
 int GetHPPercent(Scriptable* Sender)
@@ -179,19 +184,19 @@ int GetHPPercent(Scriptable* Sender)
 void HandleBitMod(ieDword &value1, ieDword value2, int opcode)
 {
 	switch(opcode) {
-		case BM_AND:
+		case OP_AND:
 			value1 = ( value1& value2 );
 			break;
-		case BM_OR:
+		case OP_OR:
 			value1 = ( value1| value2 );
 			break;
-		case BM_XOR:
+		case OP_XOR:
 			value1 = ( value1^ value2 );
 			break;
-		case BM_NAND: //this is a GemRB extension
+		case OP_NAND: //this is a GemRB extension
 			value1 = ( value1& ~value2 );
 			break;
-		case BM_SET: //this is a GemRB extension
+		case OP_SET: //this is a GemRB extension
 			value1 = value2;
 			break;
 	}
@@ -298,7 +303,7 @@ static bool StoreGetItemCore(CREItem &item, const ieResRef storename, const ieRe
 		if (si->AmountInStock > count) {
 			si->AmountInStock -= count;
 		} else {
-			store->RemoveItem(idx);
+			store->RemoveItem(si);
 		}
 		//store changed, save it
 		gamedata->SaveStore(store);
@@ -540,11 +545,11 @@ int CanSee(Scriptable* Sender, Scriptable* target, bool range, int seeflag)
 			Actor* snd = ( Actor* ) Sender;
 			dist = snd->Modified[IE_VISUALRANGE];
 		} else {
-			dist = 30;
+			dist = VOODOO_VISUAL_RANGE;
 			los = false;
 		}
 
-		if (Distance(target->Pos, Sender->Pos) > dist * 15) {
+		if (Distance(target->Pos, Sender->Pos) > dist * VOODOO_CANSEE_F) {
 			return 0;
 		}
 		if (!los) {
@@ -1116,7 +1121,7 @@ void BeginDialog(Scriptable* Sender, Action* parameters, int Flags)
 		if (scr->Type==ST_ACTOR) {
 			// might not be equal to speaker anymore due to swapping
 			Actor *talker = (Actor *) scr;
-			if (!talker->Immobile() && !(talker->GetStat(IE_STATE_ID) & STATE_SLEEP)) {
+			if (!talker->Immobile() && !(talker->GetStat(IE_STATE_ID) & STATE_SLEEP) && !(talker->AppearanceFlags&APP_NOTURN)) {
 				talker->SetOrientation(GetOrient( tar->Pos, scr->Pos), true);
 				if (talker->InParty) {
 					talker->SetStance(IE_ANI_READY);
@@ -1126,20 +1131,23 @@ void BeginDialog(Scriptable* Sender, Action* parameters, int Flags)
 		if (tar->Type==ST_ACTOR) {
 			// might not be equal to target anymore due to swapping
 			Actor *talkee = (Actor *) tar;
-			if (!talkee->Immobile() && !(talkee->GetStat(IE_STATE_ID) & STATE_SLEEP)) {
+			if (!talkee->Immobile() && !(talkee->GetStat(IE_STATE_ID) & STATE_SLEEP) && !(talkee->AppearanceFlags&APP_NOTURN)) {
 				talkee->SetOrientation(GetOrient( scr->Pos, tar->Pos), true);
 				if (talkee->InParty) {
 					talkee->SetStance(IE_ANI_READY);
 				}
+				if (!core->InCutSceneMode()) {
+					talkee->DialogInterrupt();
+				}
 			}
 		}
 	}
 
 	//increasing NumTimesTalkedTo or NumTimesInteracted
 	if (Flags & BD_TALKCOUNT) {
-		gc->SetDialogueFlags(DF_TALKCOUNT, BM_OR);
+		gc->SetDialogueFlags(DF_TALKCOUNT, OP_OR);
 	} else if ((Flags & BD_LOCMASK) == BD_INTERACT) {
-		gc->SetDialogueFlags(DF_INTERACT, BM_OR);
+		gc->SetDialogueFlags(DF_INTERACT, OP_OR);
 	}
 
 	core->GetDictionary()->SetAt("DialogChoose",(ieDword) -1);
@@ -1193,7 +1201,7 @@ void MoveBetweenAreasCore(Actor* actor, const char *area, const Point &position,
 			if (entry) {
 				// make sure the area is marked as revealed and visited
 				if (!(entry->GetAreaStatus() & WMP_ENTRY_VISITED)) {
-					entry->SetAreaStatus(WMP_ENTRY_VISIBLE|WMP_ENTRY_VISITED, BM_OR);
+					entry->SetAreaStatus(WMP_ENTRY_VISIBLE|WMP_ENTRY_VISITED, OP_OR);
 				}
 			}
 		}
@@ -1205,7 +1213,7 @@ void MoveBetweenAreasCore(Actor* actor, const char *area, const Point &position,
 	// should this perhaps be a 'selected' check or similar instead?
 	if (actor->InParty) {
 		GameControl *gc=core->GetGameControl();
-		gc->SetScreenFlags(SF_CENTERONACTOR,BM_OR);
+		gc->SetScreenFlags(SF_CENTERONACTOR,OP_OR);
 		if (newSong) {
 			game->ChangeSong(false, true);
 		}
@@ -1244,6 +1252,9 @@ void MoveToObjectCore(Scriptable *Sender, Action *parameters, ieDword flags, boo
 	}
 	//hopefully this hack will prevent lockups
 	if (!actor->InMove()) {
+		if (flags&IF_NOINT) {
+			actor->Interrupt();
+		}
 		Sender->ReleaseCurrentAction();
 		return;
 	}
@@ -1258,6 +1269,7 @@ void MoveToObjectCore(Scriptable *Sender, Action *parameters, ieDword flags, boo
 		actor->SetWait(1);
 	} else {
 		delete newaction;
+		actor->Interrupt();
 	}
 
 	Sender->ReleaseCurrentAction();
@@ -1333,7 +1345,7 @@ void AttackCore(Scriptable *Sender, Scriptable *target, int flags)
 
 	WeaponInfo wi;
 	bool leftorright = false;
-	ITMExtHeader *header = actor->GetWeapon(wi, leftorright && actor->IsDualWielding());
+	ITMExtHeader *header = actor->GetWeapon(wi, leftorright);
 	//will return false on any errors (eg, unusable weapon)
 	if (!header || !actor->WeaponIsUsable(leftorright, header)) {
 		actor->StopAttack();
@@ -1766,14 +1778,15 @@ int MoveNearerTo(Scriptable *Sender, const Point &p, int distance, int dont_rele
 		return 0;
 	}
 
-	//chasing is unbreakable
-	//TODO: is this true?
-	Sender->CurrentActionInterruptable = false;
+	// chasing is not unbreakable
+	// would prevent smart ai from dropping a target that's running away
+	//Sender->CurrentActionInterruptable = false;
 
 	Actor *actor = (Actor *)Sender;
 
 	if (!actor->InMove() || actor->Destination != p) {
-		actor->WalkTo(p, 0, distance);
+		bool always_run = core->GetGameControl()->ShouldRun(actor);
+		actor->WalkTo(p, IF_RUNNING * always_run, distance);
 	}
 
 	if (!actor->InMove()) {
@@ -2428,7 +2441,7 @@ unsigned int GetSpellDistance(const ieResRef spellres, Scriptable *Sender)
 	if (dist>0xff000000) {
 		return dist;
 	}
-	return dist*9; //FIXME: empirical constant to convert from points to (feet)
+	return dist * VOODOO_SPL_RANGE_F;
 }
 
 /* returns an item's casting distance, it depends on the used header, and targeting mode too
@@ -2651,10 +2664,6 @@ void SpellCore(Scriptable *Sender, Action *parameters, int flags)
 		parameters->int2Parameter = 1;
 	}
 
-	if ((flags&SC_AURA_CHECK) && parameters->int2Parameter && Sender->AuraPolluted()) {
-		return;
-	}
-
 	// use the passed level instead of the caster's casting level
 	if (flags&SC_SETLEVEL) {
 		if (parameters->string0Parameter[0]) {
@@ -2690,10 +2699,19 @@ void SpellCore(Scriptable *Sender, Action *parameters, int flags)
 	if (act) {
 		//move near to target
 		if ((flags&SC_RANGE_CHECK) && dist != 0xffffffff) {
-			if (PersonalDistance(tar, Sender) > dist || !Sender->GetCurrentArea()->IsVisibleLOS(Sender->Pos, tar->Pos)) {
+			if (PersonalDistance(tar, Sender) > dist) {
 				MoveNearerTo(Sender, tar, dist);
 				return;
 			}
+			if (!Sender->GetCurrentArea()->IsVisibleLOS(Sender->Pos, tar->Pos)) {
+				Spell *spl = gamedata->GetSpell(Sender->SpellResRef, true);
+				if (!(spl->Flags&SF_NO_LOS)) {
+					gamedata->FreeSpell(spl, Sender->SpellResRef, false);
+					MoveNearerTo(Sender, tar, dist);
+					return;
+				}
+				gamedata->FreeSpell(spl, Sender->SpellResRef, false);
+			}
 		}
 
 		//face target
@@ -2705,6 +2723,10 @@ void SpellCore(Scriptable *Sender, Action *parameters, int flags)
 		act->SetModal(MS_NONE);
 	}
 
+	if ((flags&SC_AURA_CHECK) && parameters->int2Parameter && Sender->AuraPolluted()) {
+		return;
+	}
+
 	int duration;
 	if (!parameters->int2Parameter) {
 		duration = Sender->CurrentActionState--;
@@ -2765,10 +2787,6 @@ void SpellPointCore(Scriptable *Sender, Action *parameters, int flags)
 		parameters->int2Parameter = 1;
 	}
 
-	if ((flags&SC_AURA_CHECK) && parameters->int2Parameter && Sender->AuraPolluted()) {
-		return;
-	}
-
 	// use the passed level instead of the caster's casting level
 	if (flags&SC_SETLEVEL) {
 		if (parameters->string0Parameter[0]) {
@@ -2783,9 +2801,20 @@ void SpellPointCore(Scriptable *Sender, Action *parameters, int flags)
 
 		Actor *act = (Actor *) Sender;
 		//move near to target
-		if ((flags&SC_RANGE_CHECK) && (PersonalDistance(parameters->pointParameter, Sender) > dist || !Sender->GetCurrentArea()->IsVisibleLOS(Sender->Pos, parameters->pointParameter))) {
-			MoveNearerTo(Sender,parameters->pointParameter, dist, 0);
-			return;
+		if (flags&SC_RANGE_CHECK) {
+			if (PersonalDistance(parameters->pointParameter, Sender) > dist) {
+				MoveNearerTo(Sender, parameters->pointParameter, dist, 0);
+				return;
+			}
+			if (!Sender->GetCurrentArea()->IsVisibleLOS(Sender->Pos, parameters->pointParameter)) {
+				Spell *spl = gamedata->GetSpell(Sender->SpellResRef, true);
+				if (!(spl->Flags&SF_NO_LOS)) {
+					gamedata->FreeSpell(spl, Sender->SpellResRef, false);
+					MoveNearerTo(Sender, parameters->pointParameter, dist, 0);
+					return;
+				}
+				gamedata->FreeSpell(spl, Sender->SpellResRef, false);
+			}
 		}
 
 		//face target
@@ -2794,6 +2823,10 @@ void SpellPointCore(Scriptable *Sender, Action *parameters, int flags)
 		act->SetModal(MS_NONE);
 	}
 
+	if ((flags&SC_AURA_CHECK) && parameters->int2Parameter && Sender->AuraPolluted()) {
+		return;
+	}
+
 	int duration;
 	if (!parameters->int2Parameter) {
 		duration = Sender->CurrentActionState--;
