@@ -533,8 +533,8 @@ public:
 	GameScript(const ieResRef ResRef, Scriptable* Myself,
 		int ScriptLevel = 0, bool AIScript = false);
 	~GameScript();
-	const char *GetName() { return this?Name:"NONE\0\0\0\0"; }
-	static void ExecuteString(Scriptable* Sender, char* String);
+	const char *GetName() { return Name; }
+	static void ExecuteString(Scriptable* Sender, const char* String);
 	static int EvaluateString(Scriptable* Sender, char* String);
 	static void ExecuteAction(Scriptable* Sender, Action* aC);
 public:
