@@ -66,7 +66,7 @@ static inline Targets *DoObjectFiltering(Scriptable *Sender, Targets *tgts, Obje
 	const targettype *tt = tgts->GetFirstTarget(m, ST_ACTOR);
 	while (tt) {
 		Actor *target = (Actor *) tt->actor;
-		if (target->ValidTarget(GA_NO_DEAD)) {
+		if (oC->objectName[0] || target->ValidTarget(GA_NO_DEAD)) {
 			tt = tgts->GetNextTarget(m, ST_ACTOR);
 		} else {
 			tt = tgts->RemoveTargetAt(m);
@@ -102,6 +102,7 @@ static inline bool DoObjectChecks(Map *map, Scriptable *Sender, Actor *target, i
 
 	// TODO: what do we check for non-actors?
 	// non-actors have a visual range (15), we should do visual range and LOS
+	// see voodooconst.h for more info, currently the rest of the code uses 30 for non-actors
 
 	if (Sender->Type == ST_ACTOR) {
 		Actor *source = (Actor *)Sender;
@@ -202,7 +203,12 @@ static Targets* EvaluateObject(Map *map, Scriptable* Sender, Object* oC, int ga_
 		Actor *ac = map->GetActor(i, true);
 		if (!ac) continue; // is this check really needed?
 		// don't return Sender in IDS targeting!
-		if (ac == Sender) continue;
+		// unless it's pst, which relies on it in 3012cut2-3012cut7.bcs
+		// FIXME: do we need more fine-grained control?
+		// FIXME: stop abusing old GF flags
+		if (!core->HasFeature(GF_AREA_OVERRIDE)) {
+			if (ac == Sender) continue;
+		}
 		bool filtered = false;
 		if (DoObjectIDSCheck(oC, ac, &filtered)) {
 			// this is needed so eg. Range trigger gets a good object
@@ -692,7 +698,7 @@ Targets *XthNearestEnemyOf(Targets *parameters, int count, int ga_flags)
 	}
 	Map *map = origin->GetCurrentArea();
 	int i = map->GetActorCount(true);
-	ga_flags |= GA_NO_UNSCHEDULED;
+	ga_flags |= GA_NO_UNSCHEDULED|GA_NO_DEAD;
 	while (i--) {
 		Actor *ac = map->GetActor(i,true);
 		if (ac == origin) continue;
