@@ -129,7 +129,7 @@ struct ModalStatesStruct {
 	unsigned int entering_str;
 	unsigned int leaving_str;
 	unsigned int failed_str;
-	bool aoe_spell;
+	unsigned int aoe_spell;
 };
 
 struct TimeStruct {
@@ -271,6 +271,7 @@ enum MODAL_SHADOW {
 #define STAT_CON_HP_MIN      2
 #define STAT_CON_HP_REGEN    3
 #define STAT_CON_FATIGUE     4
+#define STAT_CON_TNO_REGEN   4
 
 #define STAT_DEX_REACTION    0
 #define STAT_DEX_MISSILE     1
@@ -309,7 +310,8 @@ enum PauseSetting {
 enum RESOURCE_DIRECTORY {
 	DIRECTORY_CHR_PORTRAITS,
 	DIRECTORY_CHR_SOUNDS,
-	DIRECTORY_CHR_EXPORTS
+	DIRECTORY_CHR_EXPORTS,
+	DIRECTORY_CHR_SCRIPTS
 };
 
 /**
@@ -851,6 +853,9 @@ public:
 	Audio* GetAudioDrv(void) const;
 
 	void SetTickHook(EventHandler);
+
+	void SetBits(unsigned int &flag, unsigned int value, int mode) const;
+	ieDword CountBits (ieDword n) const;
 };
 
 extern GEM_EXPORT Interface * core;
