@@ -31,11 +31,12 @@
 #include "exports.h"
 
 #include "Holder.h"
-#include "PluginMgr.h"
 #include "TypeID.h"
 
 #include <cstddef>
 
+namespace GemRB {
+
 /**
  * @class Plugin
  * Base class for all GemRB plugins
@@ -47,19 +48,6 @@ public:
 	virtual ~Plugin(void);
 };
 
-template <class T>
-class PluginHolder : public Holder<T> {
-public:
-	PluginHolder()
-	{
-	}
-	PluginHolder(PluginID id)
-		: Holder<T>(static_cast<T*>(PluginMgr::Get()->GetPlugin(id)))
-	{
-	}
-	~PluginHolder()
-	{
-	}
-};
+}
 
 #endif
