@@ -171,6 +171,7 @@ namespace GemRB {
 #define UI_CRITICAL  4       //a critical hit happened
 #define UI_FAKE      8       //deplete the item but don't actually apply its effects
 #define UI_NOAURA    16      //ignore spellcasting aura checks
+#define UI_NOCHARGE  32      //don't deplete the item
 
 //used to mask off current profs
 #define PROFS_MASK  0x07
@@ -271,16 +272,6 @@ public:
 	ieDword *PrevStats;
 	ieByteSigned DeathCounters[4];   //PST specific (good, law, lady, murder)
 
-	ieResRef applyWhenHittingMelee;  //set melee effect
-	ieResRef applyWhenHittingRanged; //set ranged effect
-	ieResRef applyWhenNearLiving;    //cast spell on condition
-	ieResRef applyWhen50Damage;      //cast spell on condition
-	ieResRef applyWhen90Damage;      //cast spell on condition
-	ieResRef applyWhenEnemySighted;  //cast spell on condition
-	ieResRef applyWhenPoisoned;      //cast spell on condition
-	ieResRef applyWhenHelpless;      //cast spell on condition
-	ieResRef applyWhenAttacked;      //cast spell on condition
-	ieResRef applyWhenBeingHit;      //cast spell on condition
 	ieResRef ModalSpell;             //apply this spell once per round
 	ieResRef LingeringModalSpell;    //apply this spell once per round if the effects are lingering
 	ieResRef BardSong;               //custom bard song (updated by fx)
@@ -319,7 +310,7 @@ public:
 	ToHitStats ToHit;
 public:
 	ieDword LastExit;    //the global ID of the exit to be used
-	ieDword UsedExit;
+	ieVariable UsedExit; // name of the exit, since global id is not stable after loading a new area
 	ieResRef LastArea;
 	char ShieldRef[2];
 	char HelmetRef[2];
@@ -410,6 +401,7 @@ private:
 	void UpdateFatigue();
 	int GetSneakAttackDamage(Actor *target, WeaponInfo &wi, int &multiplier, bool weaponImmunity);
 	int GetBackstabDamage(Actor *target, WeaponInfo &wi, int multiplier, int damage) const;
+	void ApplyModal(ieResRef modalSpell);
 public:
 	Actor(void);
 	~Actor(void);
@@ -471,7 +463,8 @@ public:
 	//Which - 0 both, 1 Large, 2 Small
 	void SetPortrait(const char* ResRef, int Which=0);
 	void SetSoundFolder(const char *soundset);
-	void GetSoundFolder(char *soundset, int flag) const;
+	/* Use overrideSet to replace PCStats->SoundSet */
+	void GetSoundFolder(char *soundset, int flag, ieResRef overrideSet = 0) const;
 	/** Gets the Character Long Name/Short Name */
 	char* GetName(int which) const
 	{
@@ -689,7 +682,9 @@ public:
 	/* updates the quick slots */
 	void GetActionButtonRow(ActionButtonRow &qs);
 	/* converts the iwd2 qslot index to our internal representation */
-	int IWD2GemrbQslot (int slotindex);
+	int IWD2GemrbQslot (int slotindex) const;
+	int Gemrb2IWD2Qslot(ieByte actslot, int slotindex) const;
+	void dumpQSlots() const;
 
 	/* Handling automatic stance changes */
 	bool HandleActorStance();
@@ -749,7 +744,7 @@ public:
 	bool UseItemPoint(ieDword slot, ieDword header, const Point &point, ieDword flags);
 	bool UseItem(ieDword slot, ieDword header, Scriptable *target, ieDword flags, int damage = 0);
 	/* Deducts a charge from an item */
-	void ChargeItem(ieDword slot, ieDword header, CREItem *item, Item *itm, bool silent);
+	void ChargeItem(ieDword slot, ieDword header, CREItem *item, Item *itm, bool silent, bool expend = true);
 	/* If it returns true, then default AC=10 and the lesser the better */
 	static int IsReverseToHit();
 	/* initialize the action buttons based on class. If forced, it will override
@@ -818,6 +813,7 @@ public:
 	bool IsDualInactive() const;
 	/* true if we are dual-wielding */
 	int IsDualWielding() const;
+	int GetFavoredPenalties() const;
 	bool BlocksSearchMap() const;
 	bool CannotPassEntrance(ieDword exitID) const;
 	void UseExit(ieDword exitID);
@@ -844,7 +840,7 @@ public:
 	/* checks if the alignment matches one of the masking constants */
 	//bool MatchesAlignmentMask(ieDword mask);
 	/** untargetable by spells/attack due to invisibility or sanctuary */
-	bool Untargetable();
+	bool Untargetable(ieResRef spellRef);
 	/* returns true if this it is futile to try to harm actor (dead/sanctuaried) */
 	bool InvalidSpellTarget() const;
 	/* returns true if the spell is useless to cast on target
@@ -887,6 +883,9 @@ public:
 	void ApplyEffectCopy(Effect *oldfx, EffectRef &newref, Scriptable *Owner, ieDword param1, ieDword param2);
 	void IncreaseLastRested(int inc) { TicksLastRested += inc; }
 	bool WasClass(ieDword oldClassID) const;
+	unsigned int GetSubRace() const;
+	std::list<int> ListLevels() const;
+	void ChangeSorcererType (ieDword classIdx);
 };
 }
 
