@@ -55,6 +55,9 @@ Door::Door(TileOverlay* Overlay)
 	overlay = Overlay;
 	LinkedInfo[0] = 0;
 	OpenStrRef = (ieDword) -1;
+	open_wg_index = open_wg_count = closed_wg_index = closed_wg_count = 0;
+	closedIndex = NameStrRef = hp = ac = 0;
+	DiscoveryDiff = LockDifficulty = 0;
 }
 
 Door::~Door(void)
@@ -172,6 +175,7 @@ void Door::SetDoorLocked(int Locked, int playsound)
 	if (Locked) {
 		if (Flags & DOOR_LOCKED) return;
 		Flags|=DOOR_LOCKED;
+		SetDoorOpen(false, playsound, 0);
 		if (playsound && ( LockSound[0] != '\0' ))
 			core->GetAudioDrv()->Play( LockSound );
 	}
@@ -421,15 +425,17 @@ void Door::TryBashLock(Actor *actor)
 {
 	//Get the strength bonus against lock difficulty
 	int bonus;
+	unsigned int roll;
 
 	if (core->HasFeature(GF_3ED_RULES)) {
 		bonus = actor->GetAbilityBonus(IE_STR);
+		roll = actor->LuckyRoll(1, 100, bonus, 0);
 	} else {
 		int str = actor->GetStat(IE_STR);
 		int strEx = actor->GetStat(IE_STREXTRA);
 		bonus = core->GetStrengthBonus(2, str, strEx); //BEND_BARS_LIFT_GATES
+		roll = actor->LuckyRoll(1, 10, bonus, 0);
 	}
-	unsigned int roll = actor->LuckyRoll(1, 10, bonus, 0);
 
 	actor->FaceTarget(this);
 	if (core->HasFeature(GF_3ED_RULES)) {
