@@ -26,6 +26,7 @@
 #include "Variables.h"
 
 #include <list>
+#include <map>
 
 namespace GemRB {
 
@@ -48,10 +49,7 @@ class SpriteCover;
 
 #define MAX_SCRIPTS		8
 #define MAX_GROUND_ICON_DRAWN   3
-#define MAX_TIMER		256
 
-/** The distance of operating a trigger, container, etc. */
-#define MAX_OPERATING_DISTANCE      40 //a search square is 16x12
 /** The distance between PC's who are about to enter a new area */
 #define MAX_TRAVELING_DISTANCE      400
 
@@ -213,9 +211,7 @@ public:
 	virtual ~Scriptable(void);
 private:
 	unsigned long WaitCounter;
-	// script_timers should probably be a std::map to
-	// conserve memory (usually at most 2 ids are used)
-	ieDword script_timers[MAX_TIMER];
+	std::map<ieDword,ieDword> script_timers;
 	ieDword globalID;
 protected: //let Actor access this
 	std::list<TriggerEntry> triggers;
@@ -309,7 +305,7 @@ public:
 	void Deactivate();
 	void PartyRested();
 	ieDword GetInternalFlag() const;
-	void SetInternalFlag(int value, int mode);
+	void SetInternalFlag(unsigned int value, int mode);
 	const char* GetScriptName() const;
 	Map* GetCurrentArea() const;
 	void SetMap(Map *map);
@@ -369,7 +365,7 @@ public:
 	bool AuraPolluted();
 private:
 	/* used internally to handle start of spellcasting */
-	int SpellCast(bool instant);
+	int SpellCast(bool instant, Scriptable *target = NULL);
 	/* also part of the spellcasting process, creating the projectile */
 	void CreateProjectile(const ieResRef SpellResRef, ieDword tgt, int level, bool fake);
 	/* do some magic for the wierd/awesome wild surges */
