@@ -998,7 +998,7 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 			str->Seek( 4, GEM_CURRENT_POS ); //actor animation, unused
 			str->ReadDword( &Orientation );
 			str->ReadDword( &RemovalTime );
-			str->Seek( 4, GEM_CURRENT_POS );
+			str->Seek( 4, GEM_CURRENT_POS ); // TODO: movement restriction distance for spawns, random walk http://gibberlings3.net/forums/index.php?showtopic=21724
 			str->ReadDword( &Schedule );
 			str->ReadDword( &TalkCount );
 			str->ReadResRef( Dialog );
@@ -1059,10 +1059,10 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 					ab->BaseStats[IE_EA]=EA_EVILCUTOFF;
 				}
 				if (Flags&AF_SEEN_PARTY) {
-					ab->SetMCFlag(MC_SEENPARTY,BM_OR);
+					ab->SetMCFlag(MC_SEENPARTY,OP_OR);
 				}
 				if (Flags&AF_INVULNERABLE) {
-					ab->SetMCFlag(MC_INVULNERABLE,BM_OR);
+					ab->SetMCFlag(MC_INVULNERABLE,OP_OR);
 				}
 				if (!(Flags&AF_ENABLED)) {
 					// DifficultyMargin - only enable actors that are difficult enough vs the area difficulty
@@ -1251,8 +1251,8 @@ Map* AREImporter::GetMap(const char *ResRef, bool day_or_night)
 			str->Read(bytes, 500 );
 			bytes[500] = '\0';
 			String* text = StringFromCString(bytes);
-			map->AddMapNote( point, color, text);
 			str->ReadDword(&color); //readonly == 1
+			map->AddMapNote(point, color, text);
 			str->Seek(20, GEM_CURRENT_POS);
 		} else {
 			ieWord px,py;
@@ -2151,15 +2151,21 @@ int AREImporter::PutMapnotes( DataStream *stream, Map *map)
 			int len = 0;
 			if (mn.text) {
 				// limited to 500 *bytes* of text, convert to a multibyte encoding.
+				// we convert to MB because it fits more than if we wrote the wide characters
 				char* mbstring = MBCStringFromString(*mn.text);
 				// FIXME: depends on locale blah blah (see MBCStringFromString definition)
-				len = (std::min)(mbtowc(0, mbstring, mn.text->length()), 500);
-				stream->Write( mbstring, len);
-				free(mbstring);
+				if (mbstring) {
+					// only care about number of bytes before null so strlen is what we want despite being MB string
+					len = (std::min)(static_cast<int>(strlen(mbstring)), 500);
+					stream->Write( mbstring, len);
+					free(mbstring);
+				} else {
+					Log(WARNING, "AREImporter", "MapNote converted to an invalid multibyte sequence; cannot write it to file.\nFailed Note: %ls", mn.text->c_str());
+				}
 			}
 
 			// pad the remaining space
-			x = 500-len;
+			x = 500 - len;
 			for (int j=0;j<x/8;j++) {
 				stream->Write( filling, 8);
 			}
